@@ -16,15 +16,20 @@
  * License along with this program; if not, write to the Free
  * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
+
+// own
 #include "bomberwidget.h"
-#include "settings.h"
 
-#include <QTimer>
-#include <QGraphicsView>
+// Qt
 #include <QGraphicsItem>
+#include <QGraphicsView>
+#include <QTimer>
 
+// KDE
 #include <KLocalizedString>
-#include <sys/stat.h>
+
+// Bomber
+#include "settings.h"
 
 #define NEW_LIVE_AT_SCORE 10000;
 
@@ -36,12 +41,20 @@ static const unsigned int TICKS_PER_SECOND = 1000 / GAME_TIME_DELAY;
 /** The z-value for overlays */
 static const unsigned int OVERLAY_Z_VALUE = 1000;
 
-BomberGameWidget::BomberGameWidget(KgThemeProvider *provider, QWidget *parent) :
-    QGraphicsView(parent), m_state(State::BeforeFirstGame), m_level(0), m_lives(0), m_time(0),
-    m_renderer(provider)
+BomberGameWidget::BomberGameWidget(KgThemeProvider * provider, QWidget * parent)
+    : QGraphicsView(parent)
+    , m_state(State::BeforeFirstGame)
+    , m_level(0)
+    , m_lives(0)
+    , m_time(0)
+    , m_renderer(provider)
+    , m_soundBomb(QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("bomber/sounds/bomb.ogg")))
+    , m_soundCrash(QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("bomber/sounds/crash.ogg")))
 {
     // Gameboard
     m_board = new BomberBoard(&m_renderer, this, this);
+    connect(m_board, &BomberBoard::playBombSound, this, &BomberGameWidget::playBombSound);
+    connect(m_board, &BomberBoard::playCrashSound, this, &BomberGameWidget::playCrashSound);
     connect(m_board, &BomberBoard::onPlaneCrash, this, &BomberGameWidget::onPlaneCrashed);
     connect(m_board, &BomberBoard::onBombHit, this, &BomberGameWidget::onBombHit);
     connect(m_board, &BomberBoard::levelCleared, this, &BomberGameWidget::onLevelCleared);
@@ -145,20 +158,25 @@ void BomberGameWidget::settingsChanged()
     m_board->settingsChanged();
 }
 
-void BomberGameWidget::setSounds(bool val)
+void BomberGameWidget::setSoundsEnabled(bool enable)
 {
-    m_board->setSounds(val);
+    BomberSettings::setPlaySounds(enable);
+    BomberSettings::self()->save();
+    m_board->settingsChanged();
 }
 
 void BomberGameWidget::onPlaneCrashed()
 {
     --m_lives;
     emit livesChanged(m_lives);
-    if (m_lives <= 0) {
+    if (m_lives == 0) {
         closeGame();
     } else {
         m_board->resetPlane();
     }
+    if (BomberSettings::playSounds() == true) {
+        m_soundCrash.stop();
+    }
 }
 
 void BomberGameWidget::onBombHit()
@@ -172,6 +190,23 @@ void BomberGameWidget::onBombHit()
         ++m_lives;
         emit livesChanged(m_lives);
     }
+    if (BomberSettings::playSounds() == true) {
+        m_soundBomb.stop();
+    }
+}
+
+void BomberGameWidget::playBombSound()
+{
+    if (BomberSettings::playSounds() == true) {
+        m_soundBomb.start();
+    }
+}
+
+void BomberGameWidget::playCrashSound()
+{
+    if (BomberSettings::playSounds() == true) {
+        m_soundCrash.start();
+    }
 }
 
 void BomberGameWidget::tick()
@@ -185,7 +220,7 @@ void BomberGameWidget::tick()
     }
 }
 
-void BomberGameWidget::resizeEvent(QResizeEvent *ev)
+void BomberGameWidget::resizeEvent(QResizeEvent * ev)
 {
     QSize boardSize = ev->size();
     m_board->resize(boardSize);
@@ -213,7 +248,7 @@ void BomberGameWidget::newLevel()
     redraw();
 }
 
-void BomberGameWidget::mouseReleaseEvent(QMouseEvent *event)
+void BomberGameWidget::mouseReleaseEvent(QMouseEvent * event)
 {
     if (event->button() & Qt::LeftButton) {
         onDropBomb();
@@ -236,28 +271,28 @@ void BomberGameWidget::redraw()
     if (size().isEmpty()) {
         return;
     }
-    QGraphicsItem *item;
+    QGraphicsItem * item;
     switch (m_state) {
-    case State::BeforeFirstGame:
-        foreach (item, m_board->items()) {
-            item->hide();
-        }
-        generateOverlay();
-        m_overlay->show();
-        break;
-    case State::Running:
-        foreach (item, m_board->items()) {
-            item->show();
-        }
-        m_overlay->hide();
-        break;
-    default:
-        foreach (item, m_board->items()) {
-            item->show();
-        }
-        generateOverlay();
-        m_overlay->show();
-        break;
+        case State::BeforeFirstGame:
+            foreach (item, m_board->items()) {
+                item->hide();
+            }
+            generateOverlay();
+            m_overlay->show();
+            break;
+        case State::Running:
+            foreach (item, m_board->items()) {
+                item->show();
+            }
+            m_overlay->hide();
+            break;
+        default:
+            foreach (item, m_board->items()) {
+                item->show();
+            }
+            generateOverlay();
+            m_overlay->show();
+            break;
     }
     m_board->redraw();
     update();
@@ -279,21 +314,21 @@ void BomberGameWidget::generateOverlay()
 
     QString text;
     switch (m_state) {
-    case State::BeforeFirstGame:
-        text = i18nc("Message show to the user when the game is loaded", "Welcome to Bomber.\nClick to start a game");
-        break;
-    case State::Paused:
-        text = i18nc("Message show to the user while the game is paused", "Paused");
-        break;
-    case State::BetweenLevels:
-        text = i18nc("Message telling user which level they just completed", "You have successfully cleared level %1\n", m_level - 1)
-               + i18nc("Message telling user which level they are about to start", "On to level %1.", m_level);
-        break;
-    case State::GameOver:
-        text = i18nc("Used to tell the user that the game is over", "Game over.");
-        break;
-    default:
-        text.clear();
+        case State::BeforeFirstGame:
+            text = i18nc("Message show to the user when the game is loaded", "Welcome to Bomber.\nClick to start a game");
+            break;
+        case State::Paused:
+            text = i18nc("Message show to the user while the game is paused", "Paused");
+            break;
+        case State::BetweenLevels:
+            text = i18nc("Message telling user which level they just completed", "You have successfully cleared level %1\n", m_level - 1)
+                + i18nc("Message telling user which level they are about to start", "On to level %1.", m_level);
+            break;
+        case State::GameOver:
+            text = i18nc("Used to tell the user that the game is over", "Game over.");
+            break;
+        default:
+            text.clear();
     }
 
     QFont font;
